.. _reference:

Reference
=========

.. toctree::
    :maxdepth: 2

    ref_fields
    ref_oerplib
    ref_oerp
    ref_osv
    ref_common
    ref_db
    ref_wizard
    ref_inspect
    ref_rpc
    ref_tools
    ref_session
    ref_error

